function [Vs,Ts,Rs] = sst_new(s,T,gamma,sigma,ft,bt)
% computes the STFT Vs, the SST Ts and the reassigned STFT Rs of the signal s.
% Uses a Gaussian window with SD sigma. Computes the TF transforms at
% frequencies ft and discrete times bt.
%
% Input:
%   s: signal
%   T: signal duration
%   gamma: threshold
%   sigma: window parameter
%   ft: index of frequencies where to compute the transforms.
%       default: 1:N/2 (N=length(s))
%   bt: time index where to compute the transforms
%       default: 1:N

n = length(s);
s = s';
% Optional parameters
if nargin<5
   ft = 1:n/2;
   bt = 1:n;
end

% Padding
sleft = flipud(s(2:floor(n/2)+1));
sright = flipud(s(end-floor(n/2):end-1));
x = [sleft; s; sright];
clear xleft xright;

%% STFT and operators tau and omega

nb = length(bt);
neta = length(ft);

if (mod(n,2) == 0)
 t = T*(-1/2:1/n:1/2-1/n)'; % n coefficients in total
else
 t = T*(-(floor(n/2)/n):1/n:floor(n/2)/n)'; %n coefficients in total
end
length(t)

g = 1/sigma*exp(-pi/sigma^2*t.^2); %L1 normalized window
gp = -2*pi/sigma^2*t .* g; %g'

Vs = zeros(neta,nb);
Ts = zeros(neta,nb);
Rs = zeros(neta,nb);

%% Direct reassignment
df = ft(2)-ft(1);
db = bt(2)-bt(1);
for b=1:nb
    % Computing Vs, omega and tau in t=b
    if (mod(n,2) == 0)       
     tmp  = T*((-1).^(0:n-1))'.*fft(x(bt(b):bt(b)+n-1).*g)/n;
    else
     tmp  = T*((-1).^(0:n-1).*exp(-1i*pi*(0:n-1)/n))'.*fft(x(bt(b):bt(b)+n-1).*g)/n;   
    end
    vg = tmp(ft);
    
    if (mod(n,2) == 0)       
     tmp  = T*((-1).^(0:n-1))'.*fft(x(bt(b):bt(b)+n-1).*gp)/n;
    else
     tmp  = T*((-1).^(0:n-1).*exp(-1i*pi*(0:n-1)/n))'.*fft(x(bt(b):bt(b)+n-1).*gp)/n;   
    end
    vgp = tmp(ft);
    
    omega = ft'-real(vgp/2/1i/pi./vg);
    
    if (mod(n,2) == 0)
     tmp = T*((-1).^(0:n-1))'.*fft(x(bt(b):bt(b)+n-1).*t.*g)/n;
    else
     tmp = T*((-1).^(0:n-1).*exp(-1i*pi*(0:n-1)/n))'.*fft(x(bt(b):bt(b)+n-1).*t.*g)/n; 
    end
    vxg = n/T*tmp(ft);
    
    tau = bt(b)+real(vxg./vg);
    
    % Storing values
    Vs(:,b) = vg;
    
    % Reassignment step
     for eta=1:neta
        if abs(vg(eta))>gamma
            k = 1+round((omega(eta)-ft(1))/df);
            if k>=1 && k<=neta
                Ts(k,b) = Ts(k,b) + vg(eta);
                l = 1+round((tau(eta)-bt(1))/db);
                if l>=1 && l<=nb
                    Rs(k,l) = Rs(k,l) + abs(vg(eta));
                end
            end
        end
     end
end   
Ts = df*sigma/T*Ts;
Rs = Rs * sigma/T*df * db;
end